emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 2f05f48918: Add new SI prefixes R, Q in other places


From: Paul Eggert
Subject: master 2f05f48918: Add new SI prefixes R, Q in other places
Date: Fri, 6 Jan 2023 13:49:12 -0500 (EST)

branch: master
commit 2f05f48918ecf6e59b330709b09a36f81f7b6c48
Author: Paul Eggert <eggert@cs.ucla.edu>
Commit: Paul Eggert <eggert@cs.ucla.edu>

    Add new SI prefixes R, Q in other places
    
    * lisp/dired-x.el (dired-x--string-to-number, dired-mark-sexp):
    * lisp/dired.el (dired-re-inode-size):
    * lisp/files.el (directory-listing-before-filename-regexp):
    * src/xdisp.c (power_letter):
    * src/xdisp.c: Include stdint.h.
    Check that the prefixes suffice for ptrdiff_t.
---
 lisp/dired-x.el | 6 +++---
 lisp/dired.el   | 2 +-
 lisp/files.el   | 6 +++---
 src/xdisp.c     | 4 +++-
 4 files changed, 10 insertions(+), 8 deletions(-)

diff --git a/lisp/dired-x.el b/lisp/dired-x.el
index 560eefae02..5780f1353a 100644
--- a/lisp/dired-x.el
+++ b/lisp/dired-x.el
@@ -816,7 +816,7 @@ otherwise."
 (defun dired-x--string-to-number (str)
   "Like `string-to-number' but recognize a trailing unit prefix.
 For example, 2K is expanded to 2048.0.  The caller should make
-sure that a trailing letter in STR is one of BKkMGTPEZY."
+sure that a trailing letter in STR is one of BKkMGTPEZYRQ."
   (let* ((val (string-to-number str))
          (u (unless (zerop val)
               (aref str (1- (length str))))))
@@ -831,7 +831,7 @@ sure that a trailing letter in STR is one of BKkMGTPEZY."
       (when (and u (> u ?9))
         (when (= u ?k)
           (setq u ?K))
-        (let ((units '(?B ?K ?M ?G ?T ?P ?E ?Z ?Y)))
+        (let ((units '(?B ?K ?M ?G ?T ?P ?E ?Z ?Y ?R ?Q)))
           (while (and units (/= (pop units) u))
             (setq val (* 1024.0 val)))))
       val)))
@@ -904,7 +904,7 @@ only in the active region if `dired-mark-region' is 
non-nil."
              ;; GNU ls -hs suffixes the block count with a unit and
              ;; prints it as a float, FreeBSD does neither.
              (dired-re-inode-size "\\=\\s *\\([0-9]+\\s +\\)?\
-\\(?:\\([0-9]+\\(?:\\.[0-9]*\\)?[BkKMGTPEZY]?\\)? ?\\)"))
+\\(?:\\([0-9]+\\(?:\\.[0-9]*\\)?[BkKMGTPEZYRQ]?\\)? ?\\)"))
          (beginning-of-line)
          (forward-char 2)
          (search-forward-regexp dired-re-inode-size nil t)
diff --git a/lisp/dired.el b/lisp/dired.el
index 42d15f27a5..1f7dca802f 100644
--- a/lisp/dired.el
+++ b/lisp/dired.el
@@ -530,7 +530,7 @@ The directory name must be absolute, but need not be fully 
expanded.")
 
 (put 'dired-actual-switches 'safe-local-variable 'dired-safe-switches-p)
 
-(defvar dired-re-inode-size "[0-9 \t]*[.,0-9]*[BkKMGTPEZY]?[ \t]*"
+(defvar dired-re-inode-size "[0-9 \t]*[.,0-9]*[BkKMGTPEZYRQ]?[ \t]*"
   "Regexp for optional initial inode and file size as made by `ls -i -s'.")
 
 ;; These regexps must be tested at beginning-of-line, but are also
diff --git a/src/xdisp.c b/src/xdisp.c
index 2e962b011a..72d3bfa639 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -27621,7 +27621,9 @@ static const char power_letter[] =
     'P', /* peta */
     'E', /* exa */
     'Z', /* zetta */
-    'Y'         /* yotta */
+    'Y', /* yotta */
+    'R', /* ronna */
+    'Q'  /* quetta */
   };
 
 static void



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/files.el b/lisp/files.el
index 446c761064..e1b7a990b1 100644
--- a/lisp/files.el
+++ b/lisp/files.el
@@ -7645,7 +7645,7 @@ If DIR's free space cannot be obtained, this function 
returns nil."
         ;; This avoids recognizing `1 may 1997' as a date in the line:
         ;; -r--r--r--   1 may      1997        1168 Oct 19 16:49 README
 
         ;; The "[BkKMGTPEZY]?" below supports "ls -alh" output.
 
         ;; For non-iso date formats, we add the ".*" in order to find
         ;; the last possible match.  This avoids recognizing
@@ -7657,8 +7657,8 @@ If DIR's free space cannot be obtained, this function 
returns nil."
          ;; parentheses:
          ;; -rw-r--r-- (modified) 2005-10-22 21:25 files.el
          ;; This is not supported yet.
-    (purecopy (concat "\\([0-9][BkKMGTPEZY]? " iso
-                     "\\|.*[0-9][BkKMGTPEZY]? "
+    (purecopy (concat "\\([0-9][BkKMGTPEZYRQ]? " iso
+                     "\\|.*[0-9][BkKMGTPEZYRQ]? "
                      "\\(" western "\\|" western-comma
                       "\\|" DD-MMM-YYYY "\\|" east-asian "\\)"
                      "\\) +")))
@@ -7645,7 +7645,7 @@ If DIR's free space cannot be obtained, this function 
         ;; -r--r--r--   1 may      1997        1168 Oct 19 16:49 README
 
-        ;; The "[BkKMGTPEZY]?" below supports "ls -alh" output.
+        ;; The "[BkKMGTPEZYRQ]?" below supports "ls -alh" output.
 
         ;; For non-iso date formats, we add the ".*" in order to find